NanoafService class

Constructors

NanoafService({required NanoafConfig config, Client? httpClient})

Properties

appsflyerId String?
Returns the AppsFlyer UID after initialization.
no setter
config NanoafConfig
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cacheCompatible() Future<void>
clearCache() Future<void>
initAppsFlyer() Future<void>
Initializes AppsFlyer SDK with the dev key from config. Sets the device UUID as the custom user ID.
loadImage() Future<Uint8List?>
Tries to download the loading image from the server. Returns image bytes on success, or null if failed.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performCheck() Future<NanoafCheckOutcome>
Runs the compatibility check.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited