NanoafConfig class
Constructors
- NanoafConfig({required String baseAddress, required String configKey, required String imagePath, required String appsFlyerDevKey, required String appsFlyerAppId, int imageDownloadTimeoutSeconds = 10, int languageCheckTimeoutSeconds = 15, int pushTokenMaxAttempts = 10, int pushTokenRetryDelayMs = 500, bool debugMode = false})
-
const
Properties
- appsFlyerAppId → String
-
final
- appsFlyerDevKey → String
-
final
- baseAddress → String
-
final
- configKey → String
-
final
- debugMode → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageDownloadTimeoutSeconds → int
-
final
- imagePath → String
-
final
- languageCheckTimeoutSeconds → int
-
final
- pushTokenMaxAttempts → int
-
final
- pushTokenRetryDelayMs → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited